pub type DatetimeAVT<'a, T> = (&'a DatetimeArray<T>, Offset, Length);Expand description
Logical windowed Array View Tuple over a datetime array.
pub type DatetimeAVT<'a, T> = (&'a DatetimeArray<T>, Offset, Length);Logical windowed Array View Tuple over a datetime array.