NumericArray

Enum NumericArray 

#[repr(C, align(64))]
pub enum NumericArray { Int8(Arc<IntegerArray<i8>>), Int16(Arc<IntegerArray<i16>>), Int32(Arc<IntegerArray<i32>>), Int64(Arc<IntegerArray<i64>>), UInt8(Arc<IntegerArray<u8>>), UInt16(Arc<IntegerArray<u16>>), UInt32(Arc<IntegerArray<u32>>), UInt64(Arc<IntegerArray<u64>>), Float32(Arc<FloatArray<f32>>), Float64(Arc<FloatArray<f64>>), Null, }
NumericArray

Unified numerical array container

Purpose

Exists to unify numerical operations, simplify API’s and streamline user ergonomics.

Usage:

  • It is accessible from Array using .num(), and provides typed variant access via for e.g., .i64(), so one can drill down to the required granularity via myarr.num().i64()
  • This streamlines function implementations, and, despite the additional enum layer, matching lanes in many real-world scenarios. This is because one can for e.g., unify a function signature with impl Into<NumericArray>, and all of the subtypes, plus Array and NumericalArray, all qualify.
  • Additionally, you can then use one Integer implementation on the enum dispatch arm for all Integer variants, or, in many cases, for the entire numeric arm when they are the same.

Typecasting behaviour

  • If the enum already holds the given type (which should be known at compile-time), then using accessors like .i32() is zero-cost, as it transfers ownership.
  • If you want to keep the original, of course use .clone() beforehand.
  • If you use an accessor to a different base type, e.g., .f32() when it’s a .int32() already in the enum, it will convert it. Therefore, be mindful of performance when this occurs.

Also see:

  • Under crate::traits::type_unions , we additionally include minimal Integer, Float, Numeric and Primitive traits that for which the base Rust primitive types already qualify. These are loose wrappers over the num-traits crate to help improve type ergonomics when traits are required, but without requiring any downcasting.

Variants

Implementations

Source

impl NumericArray

pub fn len(&self) -> usize

Returns the logical length of the numeric array.

pub fn null_mask(&self) -> Option<&Bitmask>

Returns the underlying null mask, if any.

pub fn append_array(&mut self, other: &Self)

Appends all values (and null mask if present) from other into self.

Panics if the two arrays are of different variants or incompatible types.

This function uses copy-on-write semantics for arrays wrapped in Arc. If self is the only owner of its data, appends are performed in place without copying. If the array data is shared (Arc reference count > 1), the data is first cloned (so the mutation does not affect other owners), and the append is then performed on the unique copy.

This ensures that calling append_array never mutates data referenced elsewhere, but also avoids unnecessary cloning when the data is uniquely owned.

pub fn insert_rows( &mut self, index: usize, other: &Self, ) -> Result<(), MinarrowError>

Inserts all values (and null mask if present) from other into self at the specified index.

This is an O(n) operation.

Returns an error if the two arrays are of different variants or incompatible types, or if the index is out of bounds.

This function uses copy-on-write semantics for arrays wrapped in Arc.

pub fn split(self, index: usize) -> Result<(Self, Self), MinarrowError>

Splits the NumericArray at the specified index, consuming self and returning two arrays.

pub fn i32_ref(&self) -> Result<&IntegerArray<i32>, MinarrowError>

Returns a reference to the inner IntegerArray<i32> if the variant matches. No conversion or cloning is performed.

pub fn i64_ref(&self) -> Result<&IntegerArray<i64>, MinarrowError>

Returns a reference to the inner IntegerArray<i64> if the variant matches. No conversion or cloning is performed.

pub fn u32_ref(&self) -> Result<&IntegerArray<u32>, MinarrowError>

Returns a reference to the inner IntegerArray<u32> if the variant matches. No conversion or cloning is performed.

pub fn u64_ref(&self) -> Result<&IntegerArray<u64>, MinarrowError>

Returns a reference to the inner IntegerArray<u64> if the variant matches. No conversion or cloning is performed.

pub fn f32_ref(&self) -> Result<&FloatArray<f32>, MinarrowError>

Returns a reference to the inner FloatArray<f32> if the variant matches. No conversion or cloning is performed.

pub fn f64_ref(&self) -> Result<&FloatArray<f64>, MinarrowError>

Returns a reference to the inner FloatArray<f64> if the variant matches. No conversion or cloning is performed.

pub fn i32(self) -> Result<IntegerArray<i32>, MinarrowError>

Convert to IntegerArray using From/TryFrom as appropriate per conversion.

pub fn i64(self) -> Result<IntegerArray<i64>, MinarrowError>

Convert to IntegerArray using From/TryFrom as appropriate per conversion.

pub fn u32(self) -> Result<IntegerArray<u32>, MinarrowError>

Convert to IntegerArray using From/TryFrom as appropriate per conversion.

pub fn u64(self) -> Result<IntegerArray<u64>, MinarrowError>

Convert to IntegerArray using From/TryFrom as appropriate per conversion.

pub fn f32(self) -> Result<FloatArray<f32>, MinarrowError>

Convert to FloatArray using From.

pub fn f64(self) -> Result<FloatArray<f64>, MinarrowError>

Convert to FloatArray using From.

pub fn bool(self) -> Result<BooleanArray<u8>, MinarrowError>

Converts to BooleanArray.

All non-zero values become true, but the null mask is preserved.

pub fn str(self) -> Result<StringArray<u32>, MinarrowError>

Converts to StringArray by formatting each value as string.

Preserves Null mask.