macro_rules! match_array {
($self:expr, $method:ident $(, $args:expr)* $(,)?) => { ... };
}Expand description
Reduces matching boilerplate when all positive paths share the outcome
macro_rules! match_array {
($self:expr, $method:ident $(, $args:expr)* $(,)?) => { ... };
}Reduces matching boilerplate when all positive paths share the outcome