pub struct DLPackTensor { /* private fields */ }Expand description
Safe wrapper owning a legacy DLPack managed tensor. Calls the deleter on drop.
This is the return type of NdArray::to_dlpack(), analogous to how
to_apache_arrow() returns an ArrayRef that owns its lifecycle.
Implementations
Sourceimpl DLPackTensor
impl DLPackTensor
Sourcepub fn into_raw(self) -> *mut DLManagedTensor
pub fn into_raw(self) -> *mut DLManagedTensor
Raw pointer access for FFI consumers that need to take ownership e.g. when creating a PyCapsule.
After calling this, the DLPackTensor no longer owns the pointer and will not call the deleter on drop. The caller is responsible for ensuring the deleter is called.